import { Component, ViewChild, ElementRef, AfterViewInit } from '@angular/core';
import { Chart } from 'chart.js/auto';
import { ColorUsage } from '../../../../../lib/ncloud';
import { PageDesignComponent } from '../page-design/page-design.component';

// 定义JSON数据结构
interface ColorData {
  labels: string[];
  datasets: {
    label: string;
    data: number[];
    backgroundColor: string[];
    borderColor: string[];
    borderWidth: number;
    borderRadius: number;
  }[];
}

interface ColorCombination {
  colors: string[];
  icon: string;
  name: string;
  count: string;
}

@Component({
  selector: 'app-page-trends',
  standalone: true,
  templateUrl: './page-trends.component.html',
  styleUrls: ['./page-trends.component.scss']
})
export class PageTrendsComponent implements AfterViewInit {
  @ViewChild('colorChart') colorChartRef!: ElementRef;
  private colorChart: any;

  //constructor(private pageDesignComponent: PageDesignComponent) {}
  colorUsage: ColorUsage = new ColorUsage();



  /*colorData: ColorData = {
    labels: ['海洋蓝', '活力红', '森林绿', '阳光黄', '梦幻紫', '珊瑚橙'],
    datasets: [{
      label: '使用次数',
      data: [1850, 1620, 1540, 1420, 1360, 1280],
      backgroundColor: [
        '#3498db',
        '#e74c3c',
        '#2ecc71',
        '#f1c40f',
        '#9b59b6',
        '#ff7f50'
      ],
      borderColor: [
        '#2980b9',
        '#c0392b',
        '#27ae60',
        '#f39c12',
        '#8e44ad',
        '#ff6347'
      ],
      borderWidth: 1,
      borderRadius: 10
    }]
  };*/

// 增加一个方法来获取颜色使用统计结果并生成图表数据
private getColorData(): any {
    const colorUsage = this.colorUsage.getAll();
    const sortedColors = Object.entries(colorUsage).sort((a, b) => b[1] - a[1]);
    const topColors = sortedColors.slice(0, 6);

    return {
      labels: topColors.map(([color]) => color),
      datasets: [{
        label: '使用次数',
        data: topColors.map(([, count]) => count),
        backgroundColor: topColors.map(([color]) => color),
        borderColor: topColors.map(([color]) => this.darkenColor(color, 20)),
        borderWidth: 1,
        borderRadius: 10
      }]
    };
  }

  // JSON格式的热门搭配数据
  popularCombinations: ColorCombination[] = [
    {
      colors: ['#3498db', '#2c3e50'],
      icon: 'fas fa-water',
      name: '深海蓝黑',
      count: '5,678 次使用'
    },
    {
      colors: ['#e74c3c', '#f1c40f'],
      icon: 'fas fa-sun',
      name: '日落橙黄',
      count: '4,987 次使用'
    }
  ];

  ngAfterViewInit() {
    this.initChart();
  }

  private initChart() {
    const ctx = this.colorChartRef.nativeElement.getContext('2d');
    this.colorChart = new Chart(ctx, {
      type: 'bar',
      //data: this.colorData,
      data: this.getColorData(),
      options: {
        responsive: true,
        maintainAspectRatio: false,
        plugins: {
          legend: {
            display: false
          },
          title: {
            display: true,
            text: '颜色使用频率统计',
            font: {
              size: 16
            }
          }
        },
        scales: {
          y: {
            beginAtZero: true,
            grid: {
              color: 'rgba(0, 0, 0, 0.05)'
            }
          },
          x: {
            grid: {
              display: false
            }
          }
        }
      }
    });
  }


  // 生成渐变背景样式
  getGradientStyle(colors: string[]): string {
    return `background: linear-gradient(135deg, ${colors[0]}, ${colors[1]});`;
  }

// 增加一个方法来生成颜色的边框颜色
private darkenColor(color: string, percent: number): string {
  const num = parseInt(color.replace('#', ''), 16);
  const amt = Math.round(2.55 * percent);
  const R = (num >> 16) - amt;
  const G = (num >> 8 & 0x00FF) - amt;
  const B = (num & 0x0000FF) - amt;
  
  return '#' + (
    0x1000000 +
    (R < 255 ? R < 1 ? 0 : R : 255) * 0x10000 +
    (G < 255 ? G < 1 ? 0 : G : 255) * 0x100 +
    (B < 255 ? B < 1 ? 0 : B : 255)
  ).toString(16).slice(1);
}

}